#statistics

Applies [[PCA]] to reduce data dimensionality and then [[Logistic Regression]] to classify data.

Pros:
- easy, robust, flexible 
Cons:
- usually not the best classifier for chemical data